@@ -1,6 +1,6 @@
 package Pcore::Dist::Build::Issues;
 
-use Pcore -class;
+use Pcore -ansi, -class;
 use Pcore::Util::Scalar qw[blessed];
 
 has dist => ( is => 'ro', isa => InstanceOf ['Pcore::Dist'], required => 1 );
@@ -21,10 +21,8 @@ sub _build_api ($self) {
     my $scm_upstream = $self->dist->scm->upstream;
 
     return Pcore::API::Bitbucket->new(
-        {   repo_owner   => $scm_upstream->repo_owner,
-            repo_name    => $scm_upstream->repo_name,
-            api_username => $ENV->user_cfg->{'Pcore::API::Bitbucket'}->{api_username},
-            api_password => $ENV->user_cfg->{'Pcore::API::Bitbucket'}->{api_password},
+        {   namespace => $scm_upstream->namespace,
+            repo_name => $scm_upstream->repo_name,
         }
     );
 }
@@ -121,27 +119,41 @@ sub print_issues ( $self, $issues, $content = 1 ) {
         say 'No issues';
     }
     else {
-        my $tbl = P->text->table;
+        my $tbl = P->text->table(
+            style => 'pcore',
+            width => 120,
+            cols  => [
+                id => {
+                    width => 6,
+                    align => 1,
+                },
+                status   => { width => 10, },
+                priority => { width => 15, },
+                kind     => {
+                    width => 10,
+                    align => 0,
+                },
+                title => { title_align => -1, },
+            ],
+        );
 
-        $tbl->set_cols(qw[ID STATUS PRIORITY KIND TITLE]);
-        $tbl->set_col_width( 'TITLE', 100, 1 );
-        $tbl->align_col( 'ID', 'right' );
+        print $tbl->render_header;
 
         if ( blessed $issues ) {
             my $issue = $issues;
 
-            $tbl->add_row( $issue->{local_id}, $issue->status_color, $issue->priority_color, $issue->kind_color, $issue->{title} );
+            print $tbl->render_row( [ $issue->{local_id}, $issue->status_color, $issue->priority_color, $issue->kind_color, $issue->{title} ] );
 
-            print $tbl->render;
+            print $tbl->finish;
 
             say $LF, $issue->{content} || 'No content' if $content;
         }
         else {
             for my $issue ( sort { $a->status_id <=> $b->status_id or $b->priority_id <=> $a->priority_id or $b->utc_last_updated_ts <=> $a->utc_last_updated_ts } $issues->@* ) {
-                $tbl->add_row( $issue->{local_id}, $issue->status_color, $issue->priority_color, $issue->kind_color, $issue->{title} );
+                print $tbl->render_row( [ $issue->{local_id}, $issue->status_color, $issue->priority_color, $issue->kind_color, $issue->{title} ] );
             }
 
-            print $tbl->render;
+            print $tbl->finish;
 
             say 'max. 50 first issues shown';
         }
@@ -162,13 +174,13 @@ sub create_milestone ( $self, $milestone, $cb ) {
 ## -----SOURCE FILTER LOG BEGIN-----
 ##
 ## PerlCritic profile "pcore-script" policy violations:
-## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
-## │ Sev. │ Lines                │ Policy                                                                                                         │
-## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 68, 72               │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 140                  │ BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                │
-## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
+## | Sev. | Lines                | Policy                                                                                                         |
+## |======+======================+================================================================================================================|
+## |    3 | 66, 70               | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
+## |    1 | 152                  | BuiltinFunctions::ProhibitReverseSortBlock - Forbid $b before $a in sort blocks                                |
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
 __END__
